@@ -2,14 +2,10 @@ package Mojolicious::Plugin::Notifications::Alertify;
 use Mojo::Base 'Mojolicious::Plugin::Notifications::Engine';
 use Mojo::ByteStream 'b';
 use Mojo::Util qw/xml_escape quote/;
-use Mojo::JSON;
+use Mojo::JSON qw/decode_json encode_json/;
 use File::Spec;
 use File::Basename;
 
-has json => sub {
-  state $json = Mojo::JSON->new
-};
-
 has [qw/base_class base_timeout/];
 
 state $path = '/alertify/';
@@ -54,8 +50,6 @@ sub notifications {
   $js .= qq{<script>//<![CDATA[\n};
   my $noscript = "<noscript>";
 
-  my $json = $self->json;
-
   # Add notifications
   foreach (@$notify_array) {
     $js .= 'alertify.log(' . quote($_->[-1]);
